# Puppet resource definition for wrapper on firmware only updates on a server
#
# $path = path to the firmware binary OR the catalog.xml file for the idrac
# $force_restart = automatically restart the iDRAC server if reboots are needed (don't wait on user to reboot)
# $asm_hostname = the IP address of the appliance to get the firmware binaries from
# $server_firmware = List of firmware to install on server
define asm::server_update_firmware (
  $install_type    = "uri",
  $force_restart   = false,
  $path            = undef,
  $asm_hostname    = undef,
  $server_firmware = undef,
  $idrac_name      = undef
) {
  # Define iDRAC transport connection
  transport {'idrac':
    provider => 'device_file',
    name     => $idrac_name,
  }
  # Do the firmware update via IDRAC
  if $install_type == 'uri' {
    idrac_fw_installfromuri {"idrac" :
      ensure         => present,
      force_restart  => $force_restart,
      idrac_firmware => path_to_uri($server_firmware, $asm_hostname),
      transport      => Transport['idrac']
    }
  }
  else {
    idrac_fw_update { "update":
      name          => $name,
      asm_hostname  => $asm_hostname,
      path          => $path,
      force_restart => $force_restart,
      transport     => Transport['idrac']
    }
  }
}
